@@ -12,7 +12,7 @@ package MooX::Options::Role;
 use strict;
 use warnings;
 
-our $VERSION = '4.013';    # VERSION
+our $VERSION = '4.014';    # VERSION
 
 use MRO::Compat;
 use MooX::Options::Descriptive;
@@ -79,6 +79,7 @@ sub _options_prepare_descriptive {
     return \@options, \%has_to_split, \%all_options;
 }
 
+## no critic (ProhibitExcessComplexity)
 sub _options_fix_argv {
     my ( $option_data, $has_to_split, $all_options ) = @_;
 
@@ -136,21 +137,23 @@ sub _options_fix_argv {
         $arg_name .= $arg_name_without_dash;
 
         if ( my $rec = $has_to_split->{$arg_name_without_dash} ) {
-            $arg_values = shift @ARGV;
-            my $autorange
-                = defined $original_long_option
-                && exists $option_data->{$original_long_option}
-                && $option_data->{$original_long_option}{autorange};
-            foreach my $record ( $rec->records($arg_values) ) {
+            if ( $arg_values = shift @ARGV ) {
+                my $autorange
+                    = defined $original_long_option
+                    && exists $option_data->{$original_long_option}
+                    && $option_data->{$original_long_option}{autorange};
+                foreach my $record ( $rec->records($arg_values) ) {
 
-                #remove the quoted if exist to chain
-                $record =~ s/^['"]|['"]$//gx;
-                if ($autorange) {
-                    push @new_argv,
-                        map { $arg_name => $_ } _expand_autorange($record);
-                }
-                else {
-                    push @new_argv, $arg_name, $record;
+                    #remove the quoted if exist to chain
+                    $record =~ s/^['"]|['"]$//gx;
+                    if ($autorange) {
+                        push @new_argv,
+                            map { $arg_name => $_ }
+                            _expand_autorange($record);
+                    }
+                    else {
+                        push @new_argv, $arg_name, $record;
+                    }
                 }
             }
         }
@@ -169,8 +172,8 @@ sub _options_fix_argv {
     }
 
     return @new_argv;
-
 }
+## use critic
 
 sub _expand_autorange {
     my ($arg_value) = @_;
@@ -433,7 +436,7 @@ MooX::Options::Role - role that is apply to your object
 
 =head1 VERSION
 
-version 4.013
+version 4.014
 
 =head1 METHODS
 
